
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Google Inc.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Ian Rogers <ian.rogers@ContactClean.com> 
 *    http://www.sirgroane.net/2010/09/automated-javascript-unit-tests-with-xpcshell-and-hudson
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * Implementation of TAP output - http://testanything.org
 * Ian Rogers 2010 - ian.rogers@contactclean.com
 * 
 */

// for jslint
/*global dump
*/

function xpcshell_output_tap() {
	this.plan = 'N';
	this.testno = 0;
}

xpcshell_output_tap.prototype.start_suite = function(stack) {
	// done in runxpcshelltests.py
	// dump("TAP version 13\n");
};
xpcshell_output_tap.prototype.finish_suite = function(stack) {
};

xpcshell_output_tap.prototype.name_and_line = function (stack) {
	if (typeof stack === 'string') {
		return stack;
	} else {
		return stack.filename + ':' + stack.lineNumber;
	}
};

xpcshell_output_tap.prototype.info = function(stack, msg) {
	dump('# ' + this.name_and_line(stack) + "\n");
	dump('    ');
	dump(msg.split("\n").join("\n    "));
	dump("\n");
};

xpcshell_output_tap.prototype.pass = function(stack, msg) {
	this.testno++;
	dump('ok ' + this.testno + ' - ' + msg + ' # ' + this.name_and_line(stack) + "\n");
};

xpcshell_output_tap.prototype.fail = function(stack, msg) {
	this.testno++;
	dump('not ok ' + this.testno + ' - ' + msg + ' # ' + this.name_and_line(stack) + "\n");
};

xpcshell_output_tap.prototype.summary = function(stack, truePassedChecks, internalPassedChecks, failedChecks) {
	this.info(stack,
		truePassedChecks + " (+ " + internalPassedChecks + ") check(s) passed. " 
		+ failedChecks + " failed.\n"
		+ '1..' + this.testno + "\n" 
	);
};

